==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/FTPURLConnection__24ClosingInputStream.h <==
// class gnu.java.net.protocol.ftp.FTPURLConnection$ClosingInputStream

// class file dependencies
// @dep_class ebb30974db2272ef gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method$_init$f3ea7c8914d778ec(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method_info$close$6aba8b329fddcd79;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object {
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/FTPURLConnection__24ClosingInputStream.h <==
// class gnu.java.net.protocol.ftp.FTPURLConnection$ClosingInputStream

// class file dependencies
// @dep_class ebb30974db2272ef gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_
#define _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method$_init$f3ea7c8914d778ec(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$method_info$close$6aba8b329fddcd79;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vmethods	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs {
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_refs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$sub_nonrefs	gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$object {
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$vtype _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_FTPURLConnection__24ClosingInputStream_H_ */
